

DROP TABLE departamento CASCADE CONSTRAINTS;

DROP TABLE empleado CASCADE CONSTRAINTS;

DROP TABLE estadosmiti CASCADE CONSTRAINTS;

DROP TABLE estadosvulne CASCADE CONSTRAINTS;

DROP TABLE fabricantes CASCADE CONSTRAINTS;

DROP TABLE importancia CASCADE CONSTRAINTS;

DROP TABLE incumplimientosempleados CASCADE CONSTRAINTS;

DROP TABLE incumplimientospoliticas CASCADE CONSTRAINTS;

DROP TABLE log_procesos CASCADE CONSTRAINTS;

DROP TABLE maestroauditoria CASCADE CONSTRAINTS;

DROP TABLE maestropoliticasseguridad CASCADE CONSTRAINTS;

DROP TABLE maestrosesionesformativas CASCADE CONSTRAINTS;

DROP TABLE maestrovulnerabilidades CASCADE CONSTRAINTS;

DROP TABLE mitigaciones CASCADE CONSTRAINTS;

DROP TABLE notas CASCADE CONSTRAINTS;

DROP TABLE procesos CASCADE CONSTRAINTS;

DROP TABLE resultadosauditoria CASCADE CONSTRAINTS;

DROP TABLE sesionesformativas CASCADE CONSTRAINTS;

DROP TABLE tipoauditoria CASCADE CONSTRAINTS;

DROP TABLE tipoformacion CASCADE CONSTRAINTS;

CREATE TABLE departamento (
    iddepto NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    nombre  VARCHAR2(100) NOT NULL
);

ALTER TABLE departamento ADD CONSTRAINT departamento_pk PRIMARY KEY ( iddepto );

CREATE TABLE empleado (
    idempleado NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 NOCACHE ORDER )
    NOT NULL,
    iddepto    NUMBER NOT NULL,
    nif        VARCHAR2(10) NOT NULL,
    nombre     VARCHAR2(15) NOT NULL,
    apellido1  VARCHAR2(50) NOT NULL,
    apellido2  VARCHAR2(50),
    email      VARCHAR2(50),
    fechaalta  DATE DEFAULT sysdate NOT NULL,
    fechabaja  DATE
);

ALTER TABLE empleado ADD CONSTRAINT empleado_pk PRIMARY KEY ( idempleado );

CREATE TABLE estadosmiti (
    idestado NUMBER
        GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    "desc"   VARCHAR2(25) NOT NULL
);

ALTER TABLE estadosmiti ADD CONSTRAINT estadosmiti_pk PRIMARY KEY ( idestado );

ALTER TABLE estadosmiti ADD CONSTRAINT estadosmiti__un UNIQUE ( "desc" );

CREATE TABLE estadosvulne (
    idestado NUMBER
        GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    "desc"   VARCHAR2(25) NOT NULL
);

ALTER TABLE estadosvulne ADD CONSTRAINT estados_pk PRIMARY KEY ( idestado );

ALTER TABLE estadosvulne ADD CONSTRAINT estadosvulne__un UNIQUE ( "desc" );

CREATE TABLE fabricantes (
    idfabricante       NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    nombrefabricante   VARCHAR2(10) NOT NULL,
    denominacionsocial VARCHAR2(150),
    datoscontacto      VARCHAR2(250)
);

ALTER TABLE fabricantes ADD CONSTRAINT fabricantes_pk PRIMARY KEY ( idfabricante );

CREATE TABLE importancia (
    idimportancia NUMBER
        GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 NOCACHE ORDER )
    NOT NULL,
    "desc"        VARCHAR2(10) NOT NULL
);

ALTER TABLE importancia ADD CONSTRAINT importancia_pk PRIMARY KEY ( idimportancia );

ALTER TABLE importancia ADD CONSTRAINT importancia__un UNIQUE ( "desc" );

CREATE TABLE incumplimientosempleados (
    idincumpusu  NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 NOCACHE ORDER )
    NOT NULL,
    idempleado   NUMBER NOT NULL,
    fechaincumpl DATE NOT NULL
);

ALTER TABLE incumplimientosempleados ADD CONSTRAINT incumplimientosusuarios_pk PRIMARY KEY ( idincumpusu );

CREATE TABLE incumplimientospoliticas (
    idincumplimiento   NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    idpolitica         NUMBER NOT NULL,
    iddepto            NUMBER NOT NULL,
    numincumplimientos NUMBER NOT NULL,
    shortcomentarios   VARCHAR2(50) NOT NULL,
    fechregistro       DATE NOT NULL,
    comentarios        VARCHAR2(250)
);

ALTER TABLE incumplimientospoliticas ADD CONSTRAINT incumplimientospoliticas_pk PRIMARY KEY ( idincumplimiento );

CREATE TABLE log_procesos (
    id_log             NUMBER
        GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 NOCACHE ORDER )
    NOT NULL,
    fecha              DATE NOT NULL,
    procedimiento      VARCHAR2(100) NOT NULL,
    parametros_entrada VARCHAR2(700) NOT NULL,
    parametros_salida  VARCHAR2(200) NOT NULL
);

ALTER TABLE log_procesos ADD CONSTRAINT pk_log_procesos PRIMARY KEY ( id_log );

CREATE TABLE maestroauditoria (
    idauditoria      NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    idtipoauditoria  NUMBER NOT NULL,
    realizadapor     VARCHAR2(50) NOT NULL,
    fecharealizacion DATE DEFAULT sysdate NOT NULL
);

ALTER TABLE maestroauditoria ADD CONSTRAINT maestroauditoria_pk PRIMARY KEY ( idauditoria );

CREATE TABLE maestropoliticasseguridad (
    idpolitica       NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    shortdescripcion VARCHAR2(50) NOT NULL,
    descripcion      VARCHAR2(250)
);

ALTER TABLE maestropoliticasseguridad ADD CONSTRAINT politicasseguridad_pk PRIMARY KEY ( idpolitica );

CREATE TABLE maestrosesionesformativas (
    idsesion        NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    sesiontitulo    VARCHAR2(50) NOT NULL,
    agenda          VARCHAR2(500),
    idtipoformacion NUMBER NOT NULL,
    fechainicio     DATE,
    fechafin        DATE
);

ALTER TABLE maestrosesionesformativas ADD CONSTRAINT maestrosesionesformativas_pk PRIMARY KEY ( idsesion );

CREATE TABLE maestrovulnerabilidades (
    idvulnerabilidad     NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    nombrevulnerabilidad VARCHAR2(150) NOT NULL,
    idfabricante         NUMBER NOT NULL,
    idproceso            NUMBER NOT NULL,
    idestado             NUMBER NOT NULL,
    cvecode              VARCHAR2(10),
    descripcion          VARCHAR2(250),
    referencias          VARCHAR2(250),
    fechadeteccion       DATE,
    idimportancia        NUMBER NOT NULL
);

ALTER TABLE maestrovulnerabilidades ADD CONSTRAINT maestrovulnerabilidades_pk PRIMARY KEY ( idvulnerabilidad );

CREATE TABLE mitigaciones (
    idmitigacion     NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    idvulnerabilidad NUMBER NOT NULL,
    shortdescripcion VARCHAR2(50) NOT NULL,
    descripcion      VARCHAR2(250),
    idresponsable    NUMBER NOT NULL,
    fechalimite      DATE NOT NULL,
    idestado         NUMBER NOT NULL
);

ALTER TABLE mitigaciones ADD CONSTRAINT mitigaciones_pk PRIMARY KEY ( idmitigacion );

CREATE TABLE notas (
    idnota NUMBER
        GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    "desc" VARCHAR2(25) NOT NULL
);

ALTER TABLE notas ADD CONSTRAINT notas_pk PRIMARY KEY ( idnota );

ALTER TABLE notas ADD CONSTRAINT notas__un UNIQUE ( "desc" );

CREATE TABLE procesos (
    idproceso          NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    nombreproceso      VARCHAR2(50) NOT NULL,
    descripcionproceso VARCHAR2(500)
);

ALTER TABLE procesos ADD CONSTRAINT procesos_pk PRIMARY KEY ( idproceso );

CREATE TABLE resultadosauditoria (
    idincumplimiento   NUMBER NOT NULL,
    idauditoria        NUMBER NOT NULL,
    idpolitica         NUMBER NOT NULL,
    iddepto            NUMBER NOT NULL,
    numincumplimientos NUMBER NOT NULL,
    shortcomentarios   VARCHAR2(50) NOT NULL,
    fechregistro       DATE NOT NULL,
    comentarios        VARCHAR2(250)
);

CREATE TABLE sesionesformativas (
    idempleado NUMBER NOT NULL,
    idsesion   NUMBER NOT NULL,
    idnota     NUMBER DEFAULT 1 NOT NULL
);

CREATE TABLE tipoauditoria (
    idtipoauditoria NUMBER
        GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 NOCACHE ORDER )
    NOT NULL,
    "desc"          VARCHAR2(25) NOT NULL
);

ALTER TABLE tipoauditoria ADD CONSTRAINT tipoauditoria_pk PRIMARY KEY ( idtipoauditoria );

ALTER TABLE tipoauditoria ADD CONSTRAINT tipoauditoria__un UNIQUE ( "desc" );

CREATE TABLE tipoformacion (
    idtipoformacion NUMBER
        GENERATED ALWAYS AS IDENTITY ( START WITH 1 MINVALUE 1 NOCACHE ORDER )
    NOT NULL,
    "desc"          VARCHAR2(25) NOT NULL
);

ALTER TABLE tipoformacion ADD CONSTRAINT tipoformacion_pk PRIMARY KEY ( idtipoformacion );

ALTER TABLE tipoformacion ADD CONSTRAINT tipoformacion__un UNIQUE ( "desc" );

ALTER TABLE empleado
    ADD CONSTRAINT empleado_departamento_fk FOREIGN KEY ( iddepto )
        REFERENCES departamento ( iddepto );

ALTER TABLE incumplimientospoliticas
    ADD CONSTRAINT incumplimientospoliticas_departamento_fk FOREIGN KEY ( iddepto )
        REFERENCES departamento ( iddepto );

ALTER TABLE incumplimientospoliticas
    ADD CONSTRAINT incumplimientospoliticas_politicasseguridad_fk FOREIGN KEY ( idpolitica )
        REFERENCES maestropoliticasseguridad ( idpolitica );

ALTER TABLE incumplimientosempleados
    ADD CONSTRAINT incumplimientosusuarios_empleado_fk FOREIGN KEY ( idempleado )
        REFERENCES empleado ( idempleado );

ALTER TABLE maestroauditoria
    ADD CONSTRAINT maestroauditoria_tipoauditoria_fk FOREIGN KEY ( idtipoauditoria )
        REFERENCES tipoauditoria ( idtipoauditoria );

ALTER TABLE maestrosesionesformativas
    ADD CONSTRAINT maestrosesionesformativas_tipoformacion_fk FOREIGN KEY ( idtipoformacion )
        REFERENCES tipoformacion ( idtipoformacion );

ALTER TABLE maestrovulnerabilidades
    ADD CONSTRAINT maestrovulnerabilidades_estados_fk FOREIGN KEY ( idestado )
        REFERENCES estadosvulne ( idestado );

ALTER TABLE maestrovulnerabilidades
    ADD CONSTRAINT maestrovulnerabilidades_fabricantes_fk FOREIGN KEY ( idfabricante )
        REFERENCES fabricantes ( idfabricante );

ALTER TABLE maestrovulnerabilidades
    ADD CONSTRAINT maestrovulnerabilidades_importancia_fk FOREIGN KEY ( idimportancia )
        REFERENCES importancia ( idimportancia );

ALTER TABLE maestrovulnerabilidades
    ADD CONSTRAINT maestrovulnerabilidades_procesos_fk FOREIGN KEY ( idproceso )
        REFERENCES procesos ( idproceso );

ALTER TABLE mitigaciones
    ADD CONSTRAINT mitigaciones_empleado_fk FOREIGN KEY ( idresponsable )
        REFERENCES empleado ( idempleado );

ALTER TABLE mitigaciones
    ADD CONSTRAINT mitigaciones_estadosmiti_fk FOREIGN KEY ( idestado )
        REFERENCES estadosmiti ( idestado );

ALTER TABLE mitigaciones
    ADD CONSTRAINT mitigaciones_maestrovulnerabilidades_fk FOREIGN KEY ( idvulnerabilidad )
        REFERENCES maestrovulnerabilidades ( idvulnerabilidad );

ALTER TABLE resultadosauditoria
    ADD CONSTRAINT resultadosauditoria_departamento_fk FOREIGN KEY ( iddepto )
        REFERENCES departamento ( iddepto );

ALTER TABLE resultadosauditoria
    ADD CONSTRAINT resultadosauditoria_incumplimientospoliticas_fk FOREIGN KEY ( idincumplimiento )
        REFERENCES incumplimientospoliticas ( idincumplimiento );

ALTER TABLE resultadosauditoria
    ADD CONSTRAINT resultadosauditoria_maestroauditoria_fk FOREIGN KEY ( idauditoria )
        REFERENCES maestroauditoria ( idauditoria );

ALTER TABLE resultadosauditoria
    ADD CONSTRAINT resultadosauditoria_maestropoliticasseguridad_fk FOREIGN KEY ( idpolitica )
        REFERENCES maestropoliticasseguridad ( idpolitica );

ALTER TABLE sesionesformativas
    ADD CONSTRAINT sesionesformativas_empleado_fk FOREIGN KEY ( idempleado )
        REFERENCES empleado ( idempleado );

ALTER TABLE sesionesformativas
    ADD CONSTRAINT sesionesformativas_maestrosesionesformativas_fk FOREIGN KEY ( idsesion )
        REFERENCES maestrosesionesformativas ( idsesion );

ALTER TABLE sesionesformativas
    ADD CONSTRAINT sesionesformativas_notas_fk FOREIGN KEY ( idnota )
        REFERENCES notas ( idnota );


-- Tabla de log
prompt Creando la tabla Log_Procesos ......
DROP TABLE LOG_PROCESOS;
CREATE TABLE LOG_PROCESOS(
  ID_LOG				NUMBER GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 NOCACHE ORDER ) NOT NULL,
  FECHA					DATE NOT NULL,
  PROCEDIMIENTO			VARCHAR2(100) NOT NULL,
  PARAMETROS_ENTRADA	VARCHAR2(700) NOT NULL,
  PARAMETROS_SALIDA		VARCHAR2(200) NOT NULL,
  
  CONSTRAINT PK_LOG_PROCESOS PRIMARY KEY (ID_LOG) 
) ; 



